import { PreactCustomElement } from '..';
export interface Reflector<ValueType, InstanceType = PreactCustomElement> {
    /**
     * For cases where the value is stored in an attribute and the attribute is set, convert it to the desired type.
     *
     * If the format is invalid, return `null`.
     *
     * The default implementation always returns `null`, which is only useful for reflectors that never store the value in an attribute.
     *
     * @param value The value of the attribute.
     */
    parseAttribute?(value: string): ValueType | null;
    /**
     * For cases where the value is stored in an attribute, the value to use if no attribute is set, or `fromAttribute` returns `null`.
     *
     * For other where the value is stored in a property, this is the initial value.
     */
    defaultValue: ValueType;
    /**
     * For cases where the value is stored in an attribute, convert it to a string.
     *
     * If this isn't provided, String() is used to case the value from the setter.
     *
     * Returning `null` means the attribute should be removed.
     *
     * @param value The incoming value.
     */
    toAttribute?(value: ValueType): string | null;
    /**
     * This is useful in cases where the returned value is influenced by other properties on the same instance.
     *
     * In cases where the value is 'narrowed' by other properties, it's best to allow the setter to accept the 'widest' possible value.
     *
     * @param value The value, after `parseAttribute`
     * @param instance The class instance
     */
    get?(value: ValueType | null, instance: InstanceType): ValueType | null;
    /**
     * Conditionally set the value.
     *
     * @param value The incoming value.
     * @param setter A callback to set the value.
     * This value is passed to `toAttribute` if the value is stored in an attribute.
     */
    set(value: unknown, setter: (value: ValueType) => void): void;
}
