import { y, createStylesheet, __setFunctionName, __esDecorate, __runInitializers, PreactCustomElement, __classPrivateFieldGet, __classPrivateFieldSet } from '../../chunks/index.js';
import { define, reactive } from '../../chunks/define.js';
import { boolean } from '../../chunks/boolean.js';
import { string } from '../../chunks/string.js';
import { tagName } from './meta.js';
import { h } from '../../chunks/hooks.js';
import { classMap } from '../../chunks/classMap.js';

/**
 * Create a lazy-loaded component.
 *
 * @param factory A function that returns a promise for an object with a `default` property that's the target component.
 * @returns A component with the same props as the target component, but with an additional `fallback` prop.
 *
 * @example
 * ```tsx
 * const LazyComponent = lazyComponent(() => import('./MyComponent'));
 *
 * function App() {
 *  return <LazyComponent fallback={<div>Loading...</div>} other="props" go="here" />;
 * }
 * ```
 */
function lazyComponent(factory) {
    let componentPromise;
    let componentStateSetter;
    const LazyComponent = (props) => {
        const { fallback, ...rest } = props;
        const [Component, setComponent] = h(componentStateSetter);
        if (!componentStateSetter) {
            if (!componentPromise) {
                componentPromise = factory().then((m) => m.default);
            }
            // Chill, errors are handled in the function.
            // eslint-disable-next-line @typescript-eslint/no-floating-promises
            (async () => {
                const Component = await componentPromise.catch((error) => {
                    // As a fallback, return a callback that throws the error
                    return () => {
                        throw error;
                    };
                });
                // setComponent & useState have an overload that accepts a function.
                // Since the value we're setting is also a function (components are functions),
                // we need to wrap it in a function.
                componentStateSetter = () => Component;
                setComponent(componentStateSetter);
            })();
        }
        if (Component)
            return y(Component, { ...rest });
        return fallback !== null && fallback !== void 0 ? fallback : null;
    };
    return LazyComponent;
}

const shadow$1 = createStylesheet(":host{font-family:\"Inter\",-apple-system,BlinkMacSystemFont,\"San Francisco\",\"Segoe UI\",Roboto,\"Helvetica Neue\",sans-serif}.time-picker{border-radius:.75rem;box-shadow:0 .25rem .375rem -.125rem rgba(26,26,26,.2);border:.0625rem solid #e3e3e3;overflow:hidden;font-size:.8125rem}header{display:flex;align-items:center;gap:5px;padding:.25rem .5rem}header h4{padding:.5rem 0;margin:0;position:sticky;top:0;background-color:#fff;font-weight:650}.time-picker.disabled header{color:#b5b5b5}");

const LazyTimePickerMain = lazyComponent(() => import('../../chunks/TimePickerMain.js'));
function ShadowRoot(element) {
    const { disabled } = element;
    return (y("div", { class: classMap({
            'time-picker': true,
            disabled,
        }) },
        y(LazyTimePickerMain, { fallback: y("header", null,
                y("h4", null, "Select\u2026")), element: element })));
}

const shadow = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    ShadowRoot,
    styles: shadow$1
}, Symbol.toStringTag, { value: 'Module' }));

let TimePicker = (() => {
    var _TimePicker_allowRanges_accessor_storage, _TimePicker_disallowRanges_accessor_storage, _TimePicker_steps_accessor_storage, _TimePicker_disabled_accessor_storage, _TimePicker_defaultValue_accessor_storage, _TimePicker_value_accessor_storage;
    let _classDecorators = [define(tagName)];
    let _classDescriptor;
    let _classExtraInitializers = [];
    let _classThis;
    let _classSuper = PreactCustomElement;
    let _instanceExtraInitializers = [];
    let _allowRanges_decorators;
    let _allowRanges_initializers = [];
    let _disallowRanges_decorators;
    let _disallowRanges_initializers = [];
    let _steps_decorators;
    let _steps_initializers = [];
    let _disabled_decorators;
    let _disabled_initializers = [];
    let _defaultValue_decorators;
    let _defaultValue_initializers = [];
    let _value_decorators;
    let _value_initializers = [];
    _classThis = class extends _classSuper {
        get allowRanges() { return __classPrivateFieldGet(this, _TimePicker_allowRanges_accessor_storage, "f"); }
        set allowRanges(value) { __classPrivateFieldSet(this, _TimePicker_allowRanges_accessor_storage, value, "f"); }
        get disallowRanges() { return __classPrivateFieldGet(this, _TimePicker_disallowRanges_accessor_storage, "f"); }
        set disallowRanges(value) { __classPrivateFieldSet(this, _TimePicker_disallowRanges_accessor_storage, value, "f"); }
        get steps() { return __classPrivateFieldGet(this, _TimePicker_steps_accessor_storage, "f"); }
        set steps(value) { __classPrivateFieldSet(this, _TimePicker_steps_accessor_storage, value, "f"); }
        get disabled() { return __classPrivateFieldGet(this, _TimePicker_disabled_accessor_storage, "f"); }
        set disabled(value) { __classPrivateFieldSet(this, _TimePicker_disabled_accessor_storage, value, "f"); }
        get defaultValue() { return __classPrivateFieldGet(this, _TimePicker_defaultValue_accessor_storage, "f"); }
        set defaultValue(value) { __classPrivateFieldSet(this, _TimePicker_defaultValue_accessor_storage, value, "f"); }
        get value() { return __classPrivateFieldGet(this, _TimePicker_value_accessor_storage, "f"); }
        set value(value) { __classPrivateFieldSet(this, _TimePicker_value_accessor_storage, value, "f"); }
        constructor() {
            super(shadow);
            _TimePicker_allowRanges_accessor_storage.set(this, (__runInitializers(this, _instanceExtraInitializers), __runInitializers(this, _allowRanges_initializers, void 0)));
            _TimePicker_disallowRanges_accessor_storage.set(this, __runInitializers(this, _disallowRanges_initializers, void 0));
            _TimePicker_steps_accessor_storage.set(this, __runInitializers(this, _steps_initializers, void 0));
            _TimePicker_disabled_accessor_storage.set(this, __runInitializers(this, _disabled_initializers, void 0));
            _TimePicker_defaultValue_accessor_storage.set(this, __runInitializers(this, _defaultValue_initializers, void 0));
            _TimePicker_value_accessor_storage.set(this, __runInitializers(this, _value_initializers, void 0));
        }
    };
    _TimePicker_allowRanges_accessor_storage = new WeakMap();
    _TimePicker_disallowRanges_accessor_storage = new WeakMap();
    _TimePicker_steps_accessor_storage = new WeakMap();
    _TimePicker_disabled_accessor_storage = new WeakMap();
    _TimePicker_defaultValue_accessor_storage = new WeakMap();
    _TimePicker_value_accessor_storage = new WeakMap();
    __setFunctionName(_classThis, "TimePicker");
    (() => {
        var _a;
        const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create((_a = _classSuper[Symbol.metadata]) !== null && _a !== void 0 ? _a : null) : void 0;
        _allowRanges_decorators = [reactive(string())];
        _disallowRanges_decorators = [reactive(string())];
        _steps_decorators = [reactive(string())];
        _disabled_decorators = [reactive(boolean())];
        _defaultValue_decorators = [reactive(string())];
        _value_decorators = [reactive(string())];
        __esDecorate(_classThis, null, _allowRanges_decorators, { kind: "accessor", name: "allowRanges", static: false, private: false, access: { has: obj => "allowRanges" in obj, get: obj => obj.allowRanges, set: (obj, value) => { obj.allowRanges = value; } }, metadata: _metadata }, _allowRanges_initializers, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disallowRanges_decorators, { kind: "accessor", name: "disallowRanges", static: false, private: false, access: { has: obj => "disallowRanges" in obj, get: obj => obj.disallowRanges, set: (obj, value) => { obj.disallowRanges = value; } }, metadata: _metadata }, _disallowRanges_initializers, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _steps_decorators, { kind: "accessor", name: "steps", static: false, private: false, access: { has: obj => "steps" in obj, get: obj => obj.steps, set: (obj, value) => { obj.steps = value; } }, metadata: _metadata }, _steps_initializers, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _disabled_decorators, { kind: "accessor", name: "disabled", static: false, private: false, access: { has: obj => "disabled" in obj, get: obj => obj.disabled, set: (obj, value) => { obj.disabled = value; } }, metadata: _metadata }, _disabled_initializers, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _defaultValue_decorators, { kind: "accessor", name: "defaultValue", static: false, private: false, access: { has: obj => "defaultValue" in obj, get: obj => obj.defaultValue, set: (obj, value) => { obj.defaultValue = value; } }, metadata: _metadata }, _defaultValue_initializers, _instanceExtraInitializers);
        __esDecorate(_classThis, null, _value_decorators, { kind: "accessor", name: "value", static: false, private: false, access: { has: obj => "value" in obj, get: obj => obj.value, set: (obj, value) => { obj.value = value; } }, metadata: _metadata }, _value_initializers, _instanceExtraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return _classThis;
})();

export { TimePicker as default };
