function reactWrap(React, tagName, { slots = [], eventArgMap = {} } = {}) {
    const propsToSkip = new Set(['ref', 'children', ...slots]);
    const ForwardedComponent = React.forwardRef((props, userRef) => {
        const prevProps = React.useRef({});
        const elRef = React.useRef();
        React.useLayoutEffect(() => {
            const el = elRef.current;
            const prev = prevProps.current;
            // Added / changed props
            for (const [key, value] of Object.entries(props)) {
                if (propsToSkip.has(key))
                    continue;
                const prevValue = prev[key];
                if (value !== prevValue) {
                    setProperty(el, key, value, prevValue, eventArgMap);
                }
            }
            // Removed props
            for (const [key, value] of Object.entries(prev)) {
                if (propsToSkip.has(key) ||
                    Object.prototype.hasOwnProperty.call(props, key)) {
                    continue;
                }
                if (value !== undefined) {
                    setProperty(el, key, null, value, eventArgMap);
                }
            }
            prevProps.current = props;
        }, [props]);
        const ref = React.useCallback((value) => {
            elRef.current = value;
            if (userRef) {
                if (typeof userRef === 'function')
                    userRef(value);
                else
                    userRef.current = value;
            }
        }, [userRef]);
        // Map slot properties to named slots:
        const children = [
            ...slots.map((slotName) => {
                if (!props[slotName])
                    return null;
                return React.createElement('div', { slot: slotName, style: { display: 'contents' } }, props[slotName]);
            }),
            ...React.Children.toArray(props.children),
        ];
        return React.createElement(tagName, { ref }, children);
    });
    // Set the React component's displayName:
    ForwardedComponent.displayName = tagName.replace(/(?:^[a-z]+-|-)([a-z])/g, (_, i) => i.toUpperCase());
    return ForwardedComponent;
}
const listenerMap = new WeakMap();
function setProperty(el, property, value, prevValue, eventArgMap) {
    const lower = property.toLowerCase();
    if (property.startsWith('on')) {
        // block non-function event handler properties:
        if (!isValueFn(value))
            return;
        const type = lower.slice(2);
        if (!prevValue && value) {
            const listener = (event) => {
                const argMapper = eventArgMap[property];
                if (argMapper)
                    value(...argMapper(event));
                else
                    value(event);
            };
            listenerMap.set(value, listener);
            el.addEventListener(type, listener);
        }
        else if (!value && prevValue) {
            const listener = listenerMap.get(prevValue);
            el.removeEventListener(type, listener);
        }
    }
    else if (property in el) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access, @typescript-eslint/no-explicit-any
        el[property] = value;
    }
    else if (value == null) {
        el.removeAttribute(property);
    }
    else {
        el.setAttribute(property, value);
    }
}
function isValueFn(value) {
    return !!(value && typeof value === 'function');
}

export { reactWrap as default };
